@@ -59,7 +59,7 @@ namespace LightGBM {
 			return -1.0f;
 		}
 
-		std::vector<double> Eval(const double* score, const ObjectiveFunction* objective) const override {
+		std::vector<double> Eval(const double* score, const ObjectiveFunction* objective, const double*) const override {
 			double sum_loss = 0.0f;
 			if (objective == nullptr) {
 				if (weights_ == nullptr) {
@@ -87,26 +87,9 @@ namespace LightGBM {
 						const REModel* re_model = objective->GetGPModel();
 						if (re_model->GaussLikelihood()) {//Gaussian data (this is rarely used)
 							std::vector<double> minus_gp_pred(num_data_);
-							re_model->Predict(nullptr,
-								num_data_,
-								minus_gp_pred.data(),
-								false,
-								false,
-								false,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								true,
-								nullptr,
-								-1,
-								-1.,
-								nullptr,
-								nullptr,
-								true);//suppress_calc_cov_factor=true as this has been done already at the end of the last boosting update iteration
+							re_model->Predict(nullptr, num_data_, minus_gp_pred.data(), false, false, false,
+								nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+								true, nullptr, -1, -1., nullptr, nullptr, true);//suppress_calc_cov_factor=true as this has been done already at the end of the last boosting update iteration
 							// Note that the re_model already has the updated response data score - label = F_t - y 
 							//	since 'Boosting()' is called (i.e. gradients are calculated) at the end of TrainOneIter()
 #pragma omp parallel for schedule(static) reduction(+:sum_loss)
@@ -117,26 +100,9 @@ namespace LightGBM {
 						}//end Gaussian data
 						else {//non-Gaussian data
 							std::vector<double> gp_pred(num_data_);
-							re_model->Predict(nullptr,
-								num_data_,
-								gp_pred.data(),
-								false,
-								false,
-								true,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								nullptr,
-								true,
-								nullptr,
-								-1,
-								-1.,
-								nullptr,
-								score,
-								true);//suppress_calc_cov_factor=true as this has been done already at the end of the last boosting update iteration
+							re_model->Predict(nullptr, num_data_, gp_pred.data(), false, false, true,
+								nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+								true, nullptr, -1, -1., nullptr, score, true);//suppress_calc_cov_factor=true as this has been done already at the end of the last boosting update iteration
 							// Note that the re_model already has the updated training score (= F_t)
 							//	since 'Boosting()' is called (i.e. gradients are calculated) at the end of TrainOneIter()
 							//	We thus dont provide this here (see the above nullptr). This also implies
@@ -269,7 +235,7 @@ namespace LightGBM {
 			}
 		}
 
-		std::vector<double> Eval(const double* score, const ObjectiveFunction*) const override {
+		std::vector<double> Eval(const double* score, const ObjectiveFunction*, const double*) const override {
 			// get indices sorted by score, descent order
 			std::vector<data_size_t> sorted_idx;
 			for (data_size_t i = 0; i < num_data_; ++i) {
@@ -382,7 +348,7 @@ namespace LightGBM {
 			}
 		}
 
-		std::vector<double> Eval(const double* score, const ObjectiveFunction*) const override {
+		std::vector<double> Eval(const double* score, const ObjectiveFunction*, const double*) const override {
 			// get indices sorted by score, descending order
 			std::vector<data_size_t> sorted_idx;
 			for (data_size_t i = 0; i < num_data_; ++i) {
